ERROR_MSG = {}
ERROR_MSG[0] = "成功"
ERROR_MSG[-1] = "表示交易所网络连接失败"
ERROR_MSG[-2] = "表示交易所未处理请求超过许可数"
ERROR_MSG[-3] = "表示交易所每秒发送请求数超过许可数"
ERROR_MSG[3] = "表示交易所服务器未登录成功"
ERROR_MSG[4] = "用户未登录"
ERROR_MSG[5] = "非本交易所API登录"
ERROR_MSG[6] = "API版本信息出错"
ERROR_MSG[7] = "系统正在初始化"
ERROR_MSG[8] = "重复的登录"
ERROR_MSG[9] = "密码错"
ERROR_MSG[10] = "用户未找到"
ERROR_MSG[12] = "更新密码失败"
ERROR_MSG[13] = "生成密码失败"
ERROR_MSG[14] = "查询信息失败"
ERROR_MSG[16] = "撤单时未找到原始报单"
ERROR_MSG[17] = "报单在发往交易所之前被撤单"
ERROR_MSG[18] = "报单状态为已撤单状态不可撤单"
ERROR_MSG[19] = "报单状态为全部成交状态不可撤单"
ERROR_MSG[20] = "报单为错单不可撤单"
ERROR_MSG[21] = "撤单时原始报单为不可撤单状态"
ERROR_MSG[22] = "重复的报单"
ERROR_MSG[23] = "报单时未找到对应的合约信息"
ERROR_MSG[24] = "报单时买卖方向字段错误"
ERROR_MSG[25] = "报单时有效期类型字段错误"
ERROR_MSG[26] = "报单时价格字段错误"
ERROR_MSG[27] = "报单时数量字段错误"
ERROR_MSG[28] = "报单价格条件错误"
ERROR_MSG[29] = "报单时未获取到客户对应的资金信息"
ERROR_MSG[30] = "报单时资金不足"
ERROR_MSG[32] = "不能撤销其他客户报单"
ERROR_MSG[33] = "报单时价格信息不符合最小价位变动要求"
ERROR_MSG[34] = "报单时数量信息不符合最小数量变动要求"
ERROR_MSG[35] = "市价单金额不符合系统要求"
ERROR_MSG[36] = "用户信息验证失败"
ERROR_MSG[37] = "服务器分配会话信息失败"
ERROR_MSG[38] = "日内过度交易行为"
ERROR_MSG[39] = "大额报撤单行为"
ERROR_MSG[40] = "频繁撤单行为"
ERROR_MSG[41] = "最后交割日的合约不允许开仓"
ERROR_MSG[42] = "投机套保标记错误"
ERROR_MSG[43] = "开平标志错误"
ERROR_MSG[44] = "买卖方向错误"
ERROR_MSG[45] = "报单价格条件错误"
ERROR_MSG[46] = "有效期类型错误"
ERROR_MSG[47] = "成交量类型错误"
ERROR_MSG[48] = "触发条件错误"
ERROR_MSG[49] = "当前状态禁止此项操作"
ERROR_MSG[50] = "平仓时客户持仓不足"
ERROR_MSG[51] = "价格超出涨停板"
ERROR_MSG[52] = "价格跌破跌停板"
ERROR_MSG[53] = "操作标志错误"
ERROR_MSG[54] = "不支持该交易所报单或交易所字段不正确"
ERROR_MSG[55] = "获取客户端连接地址信息时出错"
ERROR_MSG[56] = "合约类型不对"
ERROR_MSG[57] = "备兑只能是卖开或买平"
ERROR_MSG[58] = "备兑开仓时标的合约持仓不足"
ERROR_MSG[59] = "距离交割日时间太短不允许开义务仓"
ERROR_MSG[60] = "组合或拆分标志错"
ERROR_MSG[61] = "不支持该组合策略"
ERROR_MSG[63] = "不支持行权操作"
