#define ONFRONTCONNECTED 0
#define ONFRONTDISCONNECTED 1
#define ONHEARTBEATWARNING 2
#define ONRSPERROR 3
#define ONRTNMARKETDATA 4
#define ONRSPUTPLOGIN 5
#define ONRSPUTPLOGOUT 6
#define ONRSPSUBSCRIBE 7
#define ONRSPUNSUBSCRIBE 8
#define ONRSPQRYEXCHANGE 9
#define ONRSPQRYINSTRUMENT 10
