int reqUtpLogin(const dict &req, int reqid);

int reqUtpLogout(const dict &req, int reqid);

int reqSubscribe(const dict &req, int reqid);

int reqUnSubscribe(const dict &req, int reqid);

int reqAuthUserPasswor(const dict &req, int reqid);

int reqQryExchange(const dict &req, int reqid);

int reqQryInstrument(const dict &req, int reqid);

