SZSE_TSS_DIALOG = 1
SZSE_TSS_PRIVATE = 2
SZSE_TSS_PUBLIC = 3
SZSE_TSS_QUERY = 4
SZSE_FTDC_OWNER_Per = 1
SZSE_FTDC_OWNER_Ex = 101
SZSE_FTDC_OWNER_Op = 102
SZSE_FTDC_OWNER_Institutional = 103
SZSE_FTDC_OWNER_Proprietary = 104
SZSE_FTDC_OWNER_Maker = 105
SZSE_FTDC_OWNER_Clear = 106
SZSE_FTDC_SIDE_Buy = '1'
SZSE_FTDC_SIDE_Sell = '2'
SZSE_FTDC_LOCK_Lock = 'Z'
SZSE_FTDC_LOCK_UnLock = 'Y'
SZSE_FTDC_OC_Open = 'O'
SZSE_FTDC_OC_Close = 'C'
SZSE_FTDC_OrdType_Market = '1'
SZSE_FTDC_OrdType_Limit = '2'
SZSE_FTDC_OrdType_BestPrice = 'U'
SZSE_FTDC_TimeInForce_GFD = '0'
SZSE_FTDC_TimeInForce_IOC = '3'
SZSE_FTDC_TimeInForce_FOK = '4'
SZSE_FTDC_Covered_Covered = 0
SZSE_FTDC_Covered_Uncovered = 1
SZSE_FTDC_Exec_Success = '0'
SZSE_FTDC_Exec_Cancel = '4'
SZSE_FTDC_Exec_Reject = '8'
SZSE_FTDC_Exec_Trade = 'F'
SZSE_FTDC_Status_Success = '0'
SZSE_FTDC_Status_Trade = '1'
SZSE_FTDC_Status_All = '2'
SZSE_FTDC_Status_Cancel = '4'
SZSE_FTDC_Status_Reject = '8'
SZSE_FTDC_HF_Speculation = '1'
SZSE_FTDC_HF_Arbitrage = '2'
SZSE_FTDC_HF_Hedge = '3'
SZSE_FTDC_OptionType_E = 'E'
SZSE_FTDC_OptionType_A = 'A'
SZSE_FTDC__PC_Options = 'O'
SZSE_FTDC__PC_Stocks = 'S'
SZSE_FTDC_CallOrPut_E = 'C'
SZSE_FTDC_CallOrPut_A = 'P'
SZSE_FTDC_ClientType_Spec = 1
SZSE_FTDC_ClientType_Arbit = 2
SZSE_FTDC_ClientType_Hedg = 3
SZSE_FTDC_ClientType_Market = 88
SZSE_FTDC_TradStatus_Normal = 0
SZSE_FTDC_TradStatus_Forbid = 1
